
<template>
  <view-grid
    ref="grid"
    :columns="columns"
    :detail="detail"
    :editFormFields="editFormFields"
    :editFormOptions="editFormOptions"
    :searchFormFields="searchFormFields"
    :searchFormOptions="searchFormOptions"
    :table="table"
    :extend="extend"
  >
  </view-grid>
</template>
    <script>
import extend from "@/extension/basic/areaInfo.js";
import { ref, defineComponent } from "vue";
export default defineComponent({
  setup() {
    const table = ref({
      key: "id",
      footer: "Foots",
      cnName: "区域信息",
      name: "areaInfo",
      url: "/AreaInfo/",
      sortName: "id",
    });
    const editFormFields = ref({
      areaCode: "",
      areaName: "",
      areaType: "",
      areaStatus: "",
      warehouseId: "",
      areaDes: "",
    });
    const editFormOptions = ref([
      [
        {
          title: "区域编号",
          required: true,
          field: "areaCode",
          type: "string",
        },
        {
          title: "区域名称",
          required: true,
          field: "areaName",
          type: "string",
        },
        {
          title: "区域类型",
          required: true,
          field: "areaType",
          type: "string",
        },
        {
          title: "区域状态",
          required: true,
          field: "areaStatus",
          type: "string",
        },
      ],
      [
        {
          title: "仓库主键",
          required: true,
          field: "warehouseId",
          type: "string",
        },
        {
          title: "区域描述",
          field: "areaDes",
          type: "textarea",
        },
      ],
    ]);
    const searchFormFields = ref({
      areaCode: "",
      areaName: "",
      areaType: "",
      areaStatus: "",
      warehouseId: "",
      areaDes: "",
    });
    const searchFormOptions = ref([
      [
        { title: "区域编号", field: "areaCode", type: "like" },
        { title: "区域名称", field: "areaName", type: "like" },
        { title: "区域类型", field: "areaType", type: "like" },
        { title: "区域状态", field: "areaStatus", type: "like" },
      ],
      [{ title: "仓库主键", field: "warehouseId", type: "like" }],
    ]);
    const columns = ref([
      {
        field: "id",
        title: "Id",
        type: "int",
        width: 90,
        hidden: true,
        readonly: true,
        require: true,
        align: "left",
      },
      {
        field: "warehouseId",
        title: "仓库主键",
        type: "string",
        width: 90,
        align: "left",
      },
      {
        field: "areaCode",
        title: "区域编号",
        type: "string",
        width: 150,
        align: "left",
      },
      {
        field: "areaName",
        title: "区域名称",
        type: "string",
        width: 150,
        align: "left",
      },
      {
        field: "areaType",
        title: "区域类型",
        type: "decimal",
        width: 90,
        align: "left",
      },
      {
        field: "areaStatus",
        title: "区域状态",
        type: "string",
        width: 90,
        align: "left",
      },
      {
        field: "areaDes",
        title: "区域描述",
        type: "int",
        width: 120,
        align: "left",
      },
      {
        field: "creater",
        title: "创建人",
        type: "string",
        width: 90,
        align: "left",
      },
      {
        field: "createDate",
        title: "创建时间",
        type: "datetime",
        width: 160,
        align: "left",
      },
      {
        field: "modifier",
        title: "修改人",
        type: "string",
        width: 100,
        align: "left",
      },
      {
        field: "modifyDate",
        title: "修改时间",
        type: "datetime",
        width: 160,
        align: "left",
      },
      {
        field: "remark",
        title: "备注",
        type: "string",
        width: 100,
        align: "left",
      },
    ]);
    const detail = ref({
      cnName: "#detailCnName",
      table: "",
      columns: [],
      sortName: "",
    });
    return {
      table,
      extend,
      editFormFields,
      editFormOptions,
      searchFormFields,
      searchFormOptions,
      columns,
      detail,
    };
  },
});
</script>
    